@@ -18,6 +18,7 @@ import logging
 import dbus
 import uuid
 from gi.repository import Gio
+from gi.repository import GLib
 from gi.repository import GObject
 
 from jarabe.model import network
@@ -74,7 +75,7 @@ class AdHocManager(GObject.GObject):
             if not self._find_connection(channel):
                 self._add_connection(channel)
 
-        settings = Gio.Settings('org.sugarlabs.network')
+        settings = Gio.Settings.new('org.sugarlabs.network')
         self._autoconnect_enabled = settings.get_boolean('adhoc-autoconnect')
 
     def start_listening(self, device):
@@ -148,8 +149,8 @@ class AdHocManager(GObject.GObject):
         will complete quickly, and long before the timeout ticks.
         """
         if self._idle_source != 0:
-            GObject.source_remove(self._idle_source)
-        self._idle_source = GObject.timeout_add_seconds(
+            GLib.source_remove(self._idle_source)
+        self._idle_source = GLib.timeout_add_seconds(
             self._AUTOCONNECT_TIMEOUT, self.__idle_check_cb)
 
     def __idle_check_cb(self):
@@ -158,6 +159,7 @@ class AdHocManager(GObject.GObject):
             self._autoconnect_adhoc()
         else:
             logging.debug('autoconnect Sugar Ad-hoc: already connected')
+        self._idle_source = 0
         return False
 
     def _autoconnect_adhoc(self):
@@ -195,7 +197,7 @@ class AdHocManager(GObject.GObject):
         settings.connection.uuid = str(uuid.uuid4())
         settings.connection.type = '802-11-wireless'
         settings.connection.autoconnect = False
-        settings.wireless.ssid = dbus.ByteArray(ssid)
+        settings.wireless.ssid = dbus.ByteArray(ssid.encode())
         settings.wireless.band = 'bg'
         settings.wireless.channel = channel
         settings.wireless.mode = 'adhoc'
@@ -235,12 +237,6 @@ class AdHocManager(GObject.GObject):
     def __get_active_connections_error_cb(self, err):
         logging.error('Error getting the active connections: %s', err)
 
-    def __activate_reply_cb(self, connection):
-        logging.debug('Ad-hoc network created: %s', connection)
-
-    def __activate_error_cb(self, err):
-        logging.error('Failed to create Ad-hoc network: %s', err)
-
     def add_access_point(self, access_point):
         """Add an access point to a network and notify the view to idicate
         the member change.
@@ -249,13 +245,13 @@ class AdHocManager(GObject.GObject):
         access_point -- Access Point
 
         """
-        if access_point.ssid.endswith(' 1'):
+        if access_point.ssid.endswith(b" 1"):
             self._networks[self._CHANNEL_1] = access_point
             self.emit('members-changed', self._CHANNEL_1, True)
-        elif access_point.ssid.endswith(' 6'):
+        elif access_point.ssid.endswith(b" 6"):
             self._networks[self._CHANNEL_6] = access_point
             self.emit('members-changed', self._CHANNEL_6, True)
-        elif access_point.ssid.endswith('11'):
+        elif access_point.ssid.endswith(b"11"):
             self._networks[self._CHANNEL_11] = access_point
             self.emit('members-changed', self._CHANNEL_11, True)
 
@@ -268,7 +264,7 @@ class AdHocManager(GObject.GObject):
         Return: Boolean
 
         """
-        for access_point in self._networks.values():
+        for access_point in list(self._networks.values()):
             if access_point is not None:
                 if access_point.model.object_path == ap_object_path:
                     return True
